// SPDX-License-Identifier: MIT
/*
 * Copyright (c) 2023 Atmark Techno,Inc.
 */

#include <stdio.h>
#include <string.h>
#include <fcntl.h>
#include <unistd.h>

#include "device-info.h"

#define IMX8MP_SOC_ID	"i.MX8MP"
#define IMX6ULL_SOC_ID	"i.MX6ULL"

enum soc get_soc(void)
{
	FILE *fp;
	char soc_id[16];

	fp = fopen("/sys/devices/soc0/soc_id", "r");
	if (fp == NULL) {
		fprintf(stderr, "fopen error: Failed to open /sys/devices/soc0/soc_id: %m\n");
		return SOC_UNKNOWN;
	}


	if (fgets(soc_id, 16, fp) == NULL) {
		fclose(fp);
		fprintf(stderr, "fgets error: %m\n");
		return SOC_UNKNOWN;
	}

	fclose(fp);

	if (strstr(soc_id, IMX8MP_SOC_ID) != NULL)
		return IMX8MP;
	if (strstr(soc_id, IMX6ULL_SOC_ID) != NULL)
		return IMX6ULL;

	fprintf(stderr, "unsupported SoC: %s\n", soc_id);
	return SOC_UNKNOWN;
}

#define IMX_OCOTP_NVMEM "/sys/bus/nvmem/devices/imx-ocotp0/nvmem"

int imx_ocotp_read(void *buf, int size)
{
	int rc = 0;
	int fd;

	fd = open(IMX_OCOTP_NVMEM, O_RDONLY);
	if (fd < 0) {
		fprintf(stderr, "Open %s failed: %m\n", IMX_OCOTP_NVMEM);
		return -1;
	}

	if (read_full(fd, buf, size) < 0) {
		fprintf(stderr, "Could not read %s: %m\n", IMX_OCOTP_NVMEM);
		rc = -1;
	}
	close(fd);
	return rc;
}
